@@ -1,12 +1,12 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
-# -*- coding: utf-8 -*-
 
 # Copyright 2009 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 import os
 
-from time import strftime
+from time import strftime, gmtime, time
+from locale import setlocale, LC_TIME
 
 from zim import __version__, __url__, \
 	__author__, __copyright__, __license__
@@ -15,16 +15,15 @@ from zim.main import HelpCommand
 
 def get_about():
 	'''Get the tagline and short description from the README'''
-	readme = open('README.txt')
+	readme = open('README.md')
 	lines = []
 	for line in readme:
-		if line.startswith('===') and 'ABOUT' in line:
-			for line in readme:
-				if line.startswith('==='):
-					break
-				else:
-					lines.append(line)
-			break
+		if line.startswith('## '):
+			break # next header
+		elif line.startswith('====') or line.startswith('!['):
+			pass # skip images and header underline
+		else:
+			lines.append(line)
 
 	lines = ''.join(lines).strip().splitlines(True)
 	assert lines and lines[0].startswith('Zim - ')
@@ -42,8 +41,9 @@ def make():
 		os.mkdir('man')
 	except OSError:
 		pass # dir already exists
+	setlocale(LC_TIME, "C")
 	manpage = open('man/zim.1', 'w')
-	manpage.write('.TH ZIM "1" "%s" "zim %s" "User Commands"\n' % (strftime('%B %Y'), __version__))
+	manpage.write('.TH ZIM "1" "%s" "zim %s" "User Commands"\n' % (strftime('%B %Y', gmtime(int(os.environ.get('SOURCE_DATE_EPOCH', time())))), __version__))
 	manpage.write('.SH NAME\nzim \\- %s\n\n' % tagline)
 	manpage.write('.SH SYNOPSIS\n%s\n' % HelpCommand.usagehelp.replace('-', r'\-'))
 	manpage.write('.SH DESCRIPTION\n%s\n' % about)
