@@ -216,6 +216,16 @@ class TestParseTree(tests.TestCase):
 		tree = ParseTree().fromstring(self.xml)
 		self.assertEqual(tree.get_heading_text(), "Head 1")
 
+	def testGetHeadingTextNestedFormat(self):
+		xml = '''<?xml version='1.0' encoding='utf-8'?>
+		<zim-tree>
+		<h level="1">Head 1 <strong>BOLD</strong> <link>URL</link></h>
+		<h level="2">Head 2</h>
+		</zim-tree>
+		'''
+		tree = ParseTree().fromstring(xml)
+		self.assertEqual(tree.get_heading_text(), "Head 1 BOLD URL")
+
 	def testSetHeadingText(self):
 		tree = ParseTree().fromstring(self.xml)
 		tree.set_heading_text('Foo')
@@ -679,6 +689,15 @@ hmmm
 		xml = '''\
 <?xml version='1.0' encoding='utf-8'?>
 <zim-tree><p><link href="http://example.com">[[example@example.com]]</link>
+</p></zim-tree>'''
+		t = self.format.Parser().parse([text])
+		self.assertEqual(t.tostring(), xml)
+
+	def testLinkWithFormatting(self):
+		text = '[[http://example.com| //Example// ]]' # spaces are crucial in this example - see issue #1306
+		xml = '''\
+<?xml version='1.0' encoding='utf-8'?>
+<zim-tree><p><link href="http://example.com"> <emphasis>Example</emphasis> </link>
 </p></zim-tree>'''
 		t = self.format.Parser().parse([text])
 		self.assertEqual(t.tostring(), xml)
@@ -923,67 +942,6 @@ class StubFile(object):
 		return self.text
 
 
-class TestOldParseTreeBuilder(tests.TestCase):
-
-	def runTest(self):
-		'''Test OldParseTreeBuilder class'''
-		# - Test \n before and after h / p / pre
-		# - Test break line into lines
-		input = '''\
-<?xml version='1.0' encoding='utf-8'?>
-<zim-tree>
-foo<h level="1">bar</h>baz
-
-dus<pre>ja</pre>hmm
-
-<h level="2">foo
-</h>bar
-
-dus ja <emphasis>hmm
-dus ja
-</emphasis>grrr
-
-<strong>foo
-
-bar
-</strong>
-<strike></strike><emphasis>   </emphasis>.
-</zim-tree>'''
-
-		wanted = '''\
-<?xml version='1.0' encoding='utf-8'?>
-<zim-tree>
-foo
-
-<h level="1">bar</h>
-baz
-
-dus
-<pre>ja
-</pre>hmm
-
-<h level="2">foo</h>
-bar
-
-dus ja <emphasis>hmm</emphasis>
-<emphasis>dus ja</emphasis>
-grrr
-
-<strong>foo</strong>
-
-<strong>bar</strong>
-
-   .
-</zim-tree>'''
-
-		from xml.etree.ElementTree import XMLParser
-		builder = XMLParser(target=OldParseTreeBuilder())
-		builder.feed(input)
-		root = builder.close()
-		tree = ParseTree(root)
-		self.assertEqual(tree.tostring(), wanted)
-
-
 class TestParseHeaderLines(tests.TestCase):
 
 	def runTest(self):
