@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 
 # Copyright 2013 Jaap Karssenberg <jaap.karssenberg@gmail.com>
 
 
-from __future__ import with_statement
+
 
 import tests
 
@@ -42,18 +41,18 @@ class TestEmitter(tests.TestCase):
 
 	def testHook(self):
 		emitter = Emitter()
-		self.assertIsNone(emitter.emit('foo', 'x'))
+		self.assertIsNone(emitter.emit_return_first('foo', 'x'))
 
 		emitter.connect('foo', lambda o, a: a * 3)
 		emitter.connect('foo', lambda o, a: a * 5)
-		self.assertEqual(emitter.emit('foo', 'x'), 'xxx')
+		self.assertEqual(emitter.emit_return_first('foo', 'x'), 'xxx')
 			# pick first result
 
 	def testSignalSetup(self):
 		emitter = FancyEmitter()
 		self.assertIsNone(emitter.state)
 
-		emitter.connect('foo', lambda o,a: None)
+		emitter.connect('foo', lambda o, a: None)
 		self.assertEqual(emitter.state, 'SETUP foo')
 
 	def testInheritance(self):
@@ -65,14 +64,14 @@ class TestEmitter(tests.TestCase):
 	def testRunSequence(self):
 		emitter = ChildEmitter()
 
-		emitter.connect('last', lambda o,l: l.append('NORMAL'))
-		emitter.connect_after('last', lambda o,l: l.append('AFTER'))
+		emitter.connect('last', lambda o, l: l.append('NORMAL'))
+		emitter.connect_after('last', lambda o, l: l.append('AFTER'))
 		seq = []
 		emitter.emit('last', seq)
 		self.assertEqual(seq, ['NORMAL', 'CLOSURE', 'AFTER'])
 
-		emitter.connect('first', lambda o,l: l.append('NORMAL'))
-		emitter.connect_after('first', lambda o,l: l.append('AFTER'))
+		emitter.connect('first', lambda o, l: l.append('NORMAL'))
+		emitter.connect_after('first', lambda o, l: l.append('AFTER'))
 		seq = []
 		emitter.emit('first', seq)
 		self.assertEqual(seq, ['CLOSURE', 'NORMAL', 'AFTER'])
