@@ -12,11 +12,25 @@ from zim.newfs.mock import os_native_path
 
 class TestFunctions(tests.TestCase):
 
-	def runTest(self):
+	def testEncodeDecode(self):
 		self.assertEqual(encode_markup_text('<foo> &bar'), '&lt;foo&gt; &amp;bar')
 		self.assertEqual(decode_markup_text('&lt;foo&gt; &amp;bar'), '<foo> &bar')
 		self.assertEqual(decode_markup_text('&lt;foo&gt; <b>&amp;bar</b>'), '<foo> &bar')
 
+	# FIXME: Can't run this without pointer over Gtk window
+	#def testGtkMenuPopup(self):
+	#	menu = Gtk.Menu()
+	#	gtk_popup_at_pointer(menu)
+	#	menu.destroy()
+
+	def testGtkMenuPopupBackward(self):
+		from zim.gui.widgets import _gtk_popup_at_pointer_backward, _ref_cache
+		menu = Gtk.Menu()
+		_gtk_popup_at_pointer_backward(menu, None, 3)
+		self.assertIn(id(menu), _ref_cache)
+		menu.destroy()
+		self.assertNotIn(id(menu), _ref_cache)
+
 
 class TestInputEntry(tests.TestCase):
 
@@ -142,12 +156,23 @@ class TestPageEntry(tests.TestCase):
 			'Test:link': '[[:Placeholder]]', # link
 			'Test:foo:bar': 'test 123',
 			'Test:bar': 'test 123',
-			'Bar': 'test 123'
+			'Bar': 'test 123',
+			'Maßnahmen': 'test 123', # unicode
+			'žžž': 'test 123' # unicde with accent
 		})
 
 		self.reference = Path('Test:foo')
+		widgets_before = tests.find_widgets(Gtk.TreeView)
 		self.entry = self.entryklass(self.notebook, self.reference)
 
+		# There's no direct way to access the model that contains the final
+		# completion items. There is no getter for it in Gtk.EntryCompletion.
+		# Instead, walk through children of all top level windows and find the
+		# view that is used to render the completion popup, that view provides
+		# access to the completion model
+		completion_view = (set(tests.find_widgets(Gtk.TreeView)) - set(widgets_before)).pop()
+		self.completion_model = completion_view.get_model()
+
 	def runTest(self):
 		'''Test PageEntry widget'''
 		entry = self.entry
@@ -178,22 +203,18 @@ class TestPageEntry(tests.TestCase):
 		self.assertTrue(entry.get_input_valid())
 		self.assertEqual(entry.get_path(), Path('Bar'))
 
-		## Test completion
-		def get_completions(entry):
-			completion = entry.get_completion()
-			model = completion.get_model()
-			return [r[0] for r in model]
-
 		for text, wanted in (
 			('', []),
 			('+', ['+bar']),
 			('+B', ['+bar']),
 			('+Bar', ['+bar']),
 			('+T', []),
-			(':', [':Bar', ':Placeholder', ':Test']),
+			(':', [':Bar', ':Maßnahmen', ':Placeholder', ':Test', ':žžž']),
 			('b', ['bar', '+bar', ':Bar']),
 			('Test:', ['Test:bar', 'Test:foo', 'Test:link']),
-
+			('Maß', ['Maßnahmen']),
+			(':Maß', [':Maßnahmen']),
+			('ž', ['žžž']),
 		):
 			# Take into account that extending the string does not reset the
 			# model but just filters in the widget - so we reset for each string
@@ -202,7 +223,7 @@ class TestPageEntry(tests.TestCase):
 			entry.set_text(text)
 			entry.update_completion()
 			self.assertTrue(entry.get_input_valid())
-			self.assertEqual(get_completions(entry), wanted)
+			self.assertEqual([r[0] for r in self.completion_model], wanted)
 
 
 class TestNamespaceEntry(TestPageEntry):
